@@ -1,8 +1,5 @@
 package Locale::Maketext::Extract;
-{
-  $Locale::Maketext::Extract::VERSION = '0.97';
-}
-
+$Locale::Maketext::Extract::VERSION = '0.99';
 use strict;
 use Locale::Maketext::Lexicon();
 
@@ -271,9 +268,12 @@ sub extract {
 sub extract_file {
     my ( $self, $file ) = @_;
 
-    local ( $/, *FH );
+    local ( *FH );
     open FH, $file or die "Error reading from file '$file' : $!";
-    my $content = scalar <FH>;
+    my $content = do {
+        local $/;
+        scalar <FH>;
+    };
 
     $self->extract( $file => $content );
     close FH;
@@ -445,13 +445,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Locale::Maketext::Extract - Extract translatable strings from source
 
 =head1 VERSION
 
-version 0.97
+version 0.99
 
 =head1 SYNOPSIS
 
